package Stanford::GCP::Bucket::Object;

# Represents an object in a Google bucket.

use strict;
use warnings;
use autodie;

use Moo;
use namespace::clean;

use POSIX qw/strftime/;

has 'bucket' => (
    is => 'rw',
    isa => sub {
        if ($_[0]->isa('Stanford::GCP::Bucket')) {
            "$_[0] is not a 'Stanford::GCP::Bucket'!" ;
        }
    },
);

has 'path' => (
  is => 'rw'
);

has 'mtime_epoch' => (
  is => 'rw'
);

has 'content_length' => (
  is => 'rw'
);

has 'md5sum_base64' => (
  is => 'rw'
);

has 'md5sum_ascii' => (
  is => 'rw'
);

sub mtime {
    my ($self) = shift ;

    # Convert epoch to current time.
    my $mtime_epoch      = $self->mtime_epoch() ;
    my $mtime_datestring = strftime '%Y-%m-%d %H:%M:%S', localtime $mtime_epoch;
    return $mtime_datestring ;
}

sub to_string {
    my ($self) = shift ;

    my $bucket_name    = $self->bucket()->name() ;
    my $path           = $self->path() ;
    my $mtime_epoch    = $self->mtime_epoch() ;
    my $content_length = $self->content_length() ;
    my $md5sum_ascii   = $self->md5sum_ascii() ;
    my $md5sum_base64  = $self->md5sum_base64() ;

    # Convert epch to current time.
    my $mtime_datestring = $self->mtime() ;

    my $rv = <<"EOS";
bucket:           $bucket_name
path:             $path
  mtime:          $mtime_datestring
  mtime_epoch:    $mtime_epoch
  content_length: $content_length
  md5sum_ascii:   $md5sum_ascii
  md5sum_base64:  $md5sum_base64
EOS
}

1;
